
var mapViewerDefaultOptions = {
	enableDebugConsole:false,
	showPanButton : true,
	showRotateToggleButton : true,
	showCalibrationInfo : false,
	showSearchButton : true,
	rotateMode : 'rotate-icon', //rotate-map or rotate-icon
	showCompass : true,
	showEye : true,
	mapMetersPerCoordinatePoint : 1 / 5, // map scale , automatically calculated is map is geo-positioned
	aproachingNode : 3, // meters before path turn to show turn directions
	onPath : 10, // meters away from path when trigger return to path directions
	avarageWalkingSpeed : 1, // average walking speed meters per second
	orientationTrigger : 30, // min orientation change in degrees triggering  directions update
	lookRadius : 100, // scan radius in meters
	positioningMode : 'external', // positioning mode to use, valid options are 'test', 'ips', 'external'
	language : 'en'
	
};

var mapMetersPerCoordinatePoint = 1 / 5;
var viewableBounds;
var mapCenter;
var map;
var navigatorCore;
var appConnector;
var popup;
var debugConsoleEnabled;
var language;

function NoClickDelay(el) {
	this.element = el;
	if( window.Touch ) this.element.addEventListener('touchstart', this, false);
}

NoClickDelay.prototype = {
	handleEvent: function(e) {
		switch(e.type) {
			case 'touchstart': this.onTouchStart(e); break;
			case 'touchmove': this.onTouchMove(e); break;
			case 'touchend': this.onTouchEnd(e); break;
		}
	},

	onTouchStart: function(e) {
		e.preventDefault();
		this.moved = false;
		this.element.addEventListener('touchmove', this, false);
		this.element.addEventListener('touchend', this, false);
	},

	onTouchMove: function(e) {
		this.moved = true;
	},

	onTouchEnd: function(e) {
		this.element.removeEventListener('touchmove', this, false);
		this.element.removeEventListener('touchend', this, false);

		if( !this.moved ) {
			// Place your code here or use the click simulation below
			var theTarget = document.elementFromPoint(e.changedTouches[0].clientX, e.changedTouches[0].clientY);
			if(theTarget.nodeType == 3) theTarget = theTarget.parentNode;

			var theEvent = document.createEvent('MouseEvents');
			theEvent.initEvent('click', true, true);
			theTarget.dispatchEvent(theEvent);
		}
	}
};

var is_android = false;

function isAndroid() {
	return is_android;
}

function updateOption(key,value) {
	mapViewerOptions[key]=value;
}



function initMap(viewerOptions) {
	var ua = navigator.userAgent;
	is_android = (ua.indexOf('Android') > -1);
	if (!isAndroid()) 
		new NoClickDelay(document.getElementById('map'));
	var navData = {
		'backboneJSON' : appConnector.getBackboneJSON(),
		'routingJSON' : appConnector.getRoutingJSON(),
		'labelsJSON' : appConnector.getLabelsJSON(),
		'staticMarkersJSON' : appConnector.getStaticMarkersJSON(),
		'pbMarkersJSON' : appConnector.getPinboardMarkersJSON(),
		'activePBMarkersJSON' : appConnector.getActivePinboardMarkersJSON(),
		'heatmapDataJSON' : appConnector.getHeatmapDataJSON(),

	}
	mapViewerOptions = $.extend(true, {}, mapViewerDefaultOptions, viewerOptions);
	//console.log(JSON.stringify(mapViewerOptions));
	language = mapViewerOptions.language;
	initSearchOptionsDef();
	debugConsoleEnabled = mapViewerOptions.enableDebugConsole;
	initMapControls(mapViewerOptions);
	initWrapperControls();

	map = createGeoPositionedMap();
	//map = createRasterImageMap();

	// init layers
	vectorSourceLabels = new ol.source.Vector({});
	vectorLayerLabels = new ol.layer.Vector({
			source : vectorSourceLabels,
			style : labelStyle()
		});
	map.addLayer(vectorLayerLabels);

	var vectorSourceIPSSignals = new ol.source.Vector({});
	var vectorLayerIPSSignals = new ol.layer.Vector({
			source : vectorSourceIPSSignals
		});
	map.addLayer(vectorLayerIPSSignals);

	var vectorSourceNavigationGrid = new ol.source.Vector({});
	var vectorLayerNavigationGrid = new ol.layer.Vector({
			source : vectorSourceNavigationGrid
		});
	map.addLayer(vectorLayerNavigationGrid);

	var vectorSourceNavigation = new ol.source.Vector({});
	var vectorLayerNavigation = new ol.layer.Vector({
			source : vectorSourceNavigation
		});
	vectorLayerNavigation.set('id', 'nav_layer')
	map.addLayer(vectorLayerNavigation);

	var vectorSourceLocation = new ol.source.Vector({});
	var vectorLayerLocation = new ol.layer.Vector({
			source : vectorSourceLocation
		});
	map.addLayer(vectorLayerLocation);
	
	// init layers
	 vectorSourceHeatMap = new ol.source.Vector({});
	 vectorLayerHeatMap = new ol.layer.Heatmap({
        source: vectorSourceHeatMap,
        blur: 10,
        radius: 30
      });
	  
	 map.addLayer(vectorLayerHeatMap);
//	vectorLayerHeatMap.setZIndex(2000);

	var vectorSourceMarkers = new ol.source.Vector({});
	var vectorLayerMarkers = new ol.layer.Vector({
			source : vectorSourceMarkers
		});
	map.addLayer(vectorLayerMarkers);

	initPopupDisplay();
	initDebugConsole(debugConsoleEnabled);
	var initialLocation = mapCenter;

	navigatorCore = new Navigator(mapViewerOptions, vectorLayerLabels, vectorLayerNavigationGrid, vectorLayerNavigation, vectorLayerLocation, vectorLayerMarkers, vectorLayerHeatMap, mapMetersPerCoordinatePoint, navData);
	navigatorCore.initNavigator();


	
}

function createGeoPositionedMap() {
	//	var imageSize = [0, 0, 1644, 2070];
	var mapExtent = mapViewerOptions.mapExtent;
	mapCenter = ol.proj.fromLonLat([mapExtent[0]+(mapExtent[2]-mapExtent[0])/2, mapExtent[1]+(mapExtent[3]-mapExtent[1])/2]);
	var mapExtentPr = ol.proj.transformExtent(mapExtent, 'EPSG:4326', 'EPSG:3857');
	//console.log("mapExtentPr " + mapExtentPr)

	viewableBounds = mapExtentPr;
	var mapMinZoom =mapViewerOptions.mapMinZoom;
	var mapMaxZoom = mapViewerOptions.mapMaxZoom;

	//var osm = new ol.layer.Tile({
	//		source : new ol.source.OSM()
	//	});
	//
	var image = new ol.layer.Image({
			source : new ol.source.ImageStatic({
				url : './assets/map.png',
				projection : 'EPSG:4326',
				//imageSize : imageSize,
				imageExtent : mapExtent
			})
		})
		var layer = new ol.layer.Tile({
			extent : mapExtentPr,
			source : new ol.source.XYZ({
				url : "./assets/tiles/{z}/{x}/{y}.jpg",
				minZoom : mapMinZoom,
				maxZoom : mapMaxZoom
			})
		});
	var scaleLineControl = new ol.control.ScaleLine({
			units : 'metric'
		});
	var map = new ol.Map({
			controls : ol.control.defaults({
				zoom : false,
				attribution : false,
				rotate : false
			}).extend([
					scaleLineControl
				]),
			interactions: ol.interaction.defaults({altShiftDragRotate:false, pinchRotate:false, dragPan:true}),
			target : 'map',
			layers : [
				//osm,
				//image
				layer
			],
			view : new ol.View({
				center : mapCenter,
				zoom : mapMinZoom,
				minZoom : mapMinZoom,
				maxZoom : mapMaxZoom,
				extent : mapExtentPr,

			})
		});

	mapMetersPerCoordinatePoint = calculateMetersPerCoordinatePoint([151.238783, -33.846106], [151.244934, -33.846106])
		//console.log('coord= '+ol.proj.fromLonLat([151.238783, -33.846106]));
		//console.log('coord= '+ol.proj.fromLonLat([151.244934, -33.846106]));
		return map;

}

function calculateMetersPerCoordinatePoint(c1, c2) {
	var wgs84Sphere = new ol.Sphere(6378137);
	// var c1_pr = ol.proj.transform(c1, projection, 'EPSG:4326');
	// var c2_pr = ol.proj.transform(c2, projection, 'EPSG:4326');
	var length = wgs84Sphere.haversineDistance(c1, c2);
	// console.log('length= '+length);
	var p1 = ol.proj.fromLonLat(c1);
	var p2 = ol.proj.fromLonLat(c2);
	var scale = length / Math.abs(p1[0] - p2[0])
		//  console.log('scale= '+scale);
		// var scale =
		return scale;
}

function createRasterImageMap() {
	var extent = [0, 0, 1232, 901];
	var mapMinZoom = 1;
	var mapMaxZoom = 5;

	//mapCenter = ol.extent.getCenter(extent),
	mapCenter = [594.34375, 371.765625]

	viewableBounds = extent;

	var projection = new ol.proj.Projection({
			code : 'xkcd-image',
			units : 'pixels',
			extent : extent
		});

	var map = new ol.Map({
			controls : ol.control.defaults({
				zoom : false,
				attribution : false,
				rotate : false,
				altShiftDragRotate:false,
				pinchRotate:false
			}).extend([
					//new app.ShowMyLocationControl(),
					//	new app.ShowSignalsControl(),
					//new app.RotationModeControl(),
					//	new app.NavigationGridModeControl()

				]),
			interactions: ol.interaction.defaults({altShiftDragRotate:false, pinchRotate:false, dragPan:true}),
			layers : [
				new ol.layer.Image({
					source : new ol.source.ImageStatic({
						url : './assets/map.png',
						projection : projection,
						imageExtent : extent
					})
				})
			],
			target : document.getElementById('map'),
			view : new ol.View({
				projection : projection,
				center : mapCenter,
				extent : extent,
				zoom : mapMinZoom,
				maxZoom : mapMaxZoom,
				minZoom : mapMinZoom,
			})
		});
	return map;

}

function initMapControls(mapViewerOptions) {
	var bodyEl = $(document.body);



		if (mapViewerOptions.showSearchButton == true) {
		var a = jQuery('<a/>', {
				//id : 'foo',
				href : '#',
				id : "btnSearch",
				class : "search-icon"
			}).appendTo(bodyEl);

		a.bind("click", function (event, ui) {
		//alert('working')
		$('#search_options').show()
		$('#keyword_search').hide()
		
		var modal = $('#trailItemsSearch')
		var div = modal.find('#items-list-display');
		$(div).empty();
		$('#trailItemsSearch').modal('toggle');

		});
		var title = $('#trailItemsSearch').find('#search-modal-title')
		title.text(langString (language, 'search_modal_name'));

	};
	
	
	
	if (mapViewerOptions.showCompass) {
		var a = jQuery('<a/>', {
				//id : 'foo',
				href : '#',
				id : "compass_display",
				class : "compass_display"
			}).appendTo(bodyEl);
	};


	
}

function initPopupDisplay() {

	popup = new ol.Overlay.Popup();
	map.addOverlay(popup);

	map.on('click', function (evt) {

		// Hide existing popup and reset it's offset
		popup.hide();

		// Attempt to find a feature in one of the visible vector layers
		var feature = map.forEachFeatureAtPixel(evt.pixel, function (feature, layer) {
				return feature;
			});

		if (feature && feature.get("type") == "marker-with-popup") {

			//console.log(feature.get("type"));
			var coord = feature.getGeometry().getCoordinates();
			var props = feature.getProperties();
			//console.log('You popup_content: ' + feature.get('popup_content'));

			popup.show(coord, createMapPoupHTML(feature.getId()));

		}

	});



	// change mouse cursor when over marker
	map.on('pointermove', function (e) {
		if (e.dragging) {
			//$(element).popover('destroy');
			return;
		}
		//	var pixel = map.getEventPixel(e.originalEvent);
		//	var hit = map.hasFeatureAtPixel(pixel);
		//	map.getTarget().style.cursor = hit ? 'pointer' : '';
	});

}

function initWrapperControls() {

	$("#navigation_overlay").hide();
	$("#selection_overlay").hide();

	$("#btnSelect").bind("click", function (event, ui) {
		$("#navigation_overlay").show();
		$("#selection_overlay").show();
	});

	$("#btnSelect").bind("click", function (event, ui) {
		$("#navigation_overlay").show();
		$("#selection_overlay").show();
	});

	$("#btnNavigate").bind("click", function (event, ui) {
		$("#navigation_overlay").show();
	});

	$("#btnDismissNav").bind("click", function (event, ui) {
		navigatorCore.navPathAssistant.stopNavigationAssistance();
		$("#navigation_overlay").hide();
	});

	$("#btnDismissSelection").bind("click", function (event, ui) {
		$("#navigation_overlay").hide();
		$("#selection_overlay").hide();
		$("#main_bar").show();
	});

	$("#eye_overlay").hide();
   


	$("#btnDismissEye").bind("click", function (event, ui) {
		dismissEye();

	});

$('#item-details-modal-sm').on('show.bs.modal', function (event) {
	var a = $(event.relatedTarget) // Button that triggered the modal

	var targer_id = $(event.relatedTarget).attr('target_id');

	var itemData = navigatorCore.navItemFLayer.boundItemsData[targer_id];
	var itemID = itemData['id'];
	var modal = $(this)

	var div = modal.find('#item-modal-cont')

	$(div).empty();
	
	var a;
	if (itemData['location_id']) {
		var linkURL = 'http://popup-link?locationid=' + itemData['location_id'];
		a = jQuery('<a/>', {
				//id : 'foo',
				href : linkURL,
				id : "item-map-popup-link",
				class : "item-map-popup-link"
			}).appendTo(div);
	} else  {
				a = jQuery('<div/>', {
			//id : 'foo',
			//href : '#',
			id : "item-map-popup-link",
			class : "item-map-popup-link"
		}).appendTo(div);
		
	}


	//a.attr('target-id', itemID);


	var divImg = jQuery('<div/>', {
			href : '#',
			id : "item-map-popup-img",
			class : "item-map-popup-img"
		}).appendTo(a);

	var img = jQuery('<img/>', {
			id : "item-map-popup-img-img",
			class : "item-map-popup-img-img",
			src : itemData['popupPreviewURL']
		}).appendTo(divImg);

	var divTitleBar = jQuery('<div/>', {
			href : '#',
			id : "item-map-popup-title-bar",
			class : "item-map-popup-title-bar"
		}).appendTo(div);

	var span = jQuery('<span/>', {
			id : "item-map-popup-text",
			class : "item-map-popup-text",
			text : itemData['popupHeading']
		}).appendTo(divTitleBar);



	var nextEvent = navigatorCore.navItemFLayer.getNextEvent(itemID);
	if (nextEvent) {

		var span1 = jQuery('<span/>', {
				id : "item-map-popup-event-type",
				class : "item-map-popup-event-type",
				text : nextEvent.type + ' at: '
			}).appendTo(divTitleBar);

		var span3 = jQuery('<span/>', {
				id : "item-map-popup-event-time",
				class : "item-map-popup-event-time",
				text : nextEvent.start_time
			}).appendTo(divTitleBar);

	}
	jQuery('<br/>', {}).appendTo(span);

	var distanceTo = navigatorCore.findDistanceToItemM(itemData['id']);
	if (distanceTo)
		var spanDistance = jQuery('<span/>', {
				id : "item-map-popup-distance",
				class : "item-map-popup-distance",
				text : distanceTo
			}).appendTo(divImg);

	var span_bottom_toolbar = jQuery('<span/>', {
			id : "item-map-popup-bottom-toolbar",
			class : "item-map-popup-bottom-toolbar"
		}).appendTo(div);

	var a_dir = jQuery('<a/>', {
			href : '#',
			id : "item-map-popup-get-directions-link",
			class : "item-map-popup-get-directions-link",
			onclick : "getDirections(event)",
			text : langString (language,'directions')
		}).appendTo(span_bottom_toolbar);

	a_dir.attr('target-id', itemID);
	
		if (itemData['location_id']) {
		var linkURL = 'http://popup-link?locationid=' + itemData['location_id'];

		var link = jQuery('<a/>', {
				href : linkURL,
				class : "item-map-popup-view-more",
				//class : "item-map-popup-get-directions-link",
				text : 'Info'
			}).appendTo(span_bottom_toolbar);
	}

	if (canBeAddedToMyDay(itemData.marker_type)) {
		var linkURL = 'http://add-to-my-day-link?locationid=' + itemData['location_id'] + '&markerid=' + itemData['id'];

		var link = jQuery('<a/>', {
				href : linkURL,
				class : "item-map-popup-add-to-my-day-link",
				text : langString (language, 'add')
			}).appendTo(span_bottom_toolbar);
	}

})



	$('#trailItems').on('show.bs.modal', function (event) {
		//var a = $(event.relatedTarget) // Button that triggered the modal
		//console.log("you clicked " + );
		//	var targer_id = $(event.relatedTarget).attr('target_id');
		//	var itemData = navigatorCore.navItemFLayer.boundItemsData[targer_id];

		var modal = $(this)
			var div = modal.find('#items-list-display');
		$(div).empty();

		var boundItemsData = navigatorCore.navItemFLayer.boundItemsData;
		for (var key in boundItemsData) {
			var itemData = boundItemsData[key];

			var item_div = jQuery('<div/>', {
					//	href : '#',
					class : "list-group-item",
					//	onclick : "selectItem()",

				}).appendTo(div);

			item_div.attr('target-id', itemData.id);

			var div_img_cont = jQuery('<div/>', {
					//	href : '#',
					class : "item-list-img-cont",
					//	onclick : "selectItem()",

				}).appendTo(item_div);

			var img = jQuery('<img/>', {
					class : "pull-left item-list-img",
					src : itemData['popupPreviewURL']
				}).appendTo(div_img_cont);

			var distanceTo = navigatorCore.findDistanceToItemM(itemData['id']);

			var span = jQuery('<span/>', {
					class : "label label-success label-pill",
					text : distanceTo
				}).appendTo(div_img_cont)

				var div_pr_cont = jQuery('<div/>', {
					//	href : '#',
					class : "item-list-pr-cont",
					//	onclick : "selectItem()",

				}).appendTo(item_div);

			var h4 = jQuery('<h4/>', {
					class : "list-group-item-heading",
					text : itemData['popupHeading'],
				}).appendTo(div_pr_cont);

			var p = jQuery('<p/>', {
					class : "list-group-item-text ",
					html : itemData['popupText']
				}).appendTo(div_pr_cont)

				var nextEvent = navigatorCore.navItemFLayer.getNextEvent(itemData['id']);
			if (nextEvent) {
				var info = jQuery('<span/>', {
						class : "item-list-event-info",
					}).appendTo(div_pr_cont);

				var span1 = jQuery('<span/>', {
						class : "item-list-event-type",
						text : nextEvent.type + ':'
					}).appendTo(info);

				var timeTo = displayTimeFromSecondsToHoursAndMinutes(nextEvent.start_time_sec - getSecondsFromDayStart(new Date()))
					//console.log('timeTo ' + timeTo);
					var span2 = jQuery('<span/>', {
						class : "item-list-event-timeto",
						text : "in " + timeTo
					}).appendTo(info);

				var span3 = jQuery('<span/>', {
						class : "item-list-event-time",
						text : nextEvent.start_time
					}).appendTo(info);

				var span4 = jQuery('<span/>', {
						class : "item-list-event-status",
						text : nextEvent.status
					}).appendTo(info);

				if (nextEvent.status == 'open')
					span4.addClass('event-open')

					if (nextEvent.status == 'closed')
						span4.addClass('event-closed')

			}

			var a_dir = jQuery('<a/>', {
					href : '#',
					class : "item-list-get-directions-link",
					onclick : "getDirections(event)",
					text : langString (language, 'directions')
				}).appendTo(div_pr_cont);

			a_dir.attr('target-id', itemData['id']);

		}

	})

	$('#trailEvents').on('show.bs.modal', function (event) {
		//var a = $(event.relatedTarget) // Button that triggered the modal
		//console.log("you clicked " + );
		//	var targer_id = $(event.relatedTarget).attr('target_id');
		//	var itemData = navigatorCore.navItemFLayer.boundItemsData[targer_id];

		var modal = $(this)
			var div = modal.find('#events-list-display');
		$(div).empty();
		var d = new Date();
		var day = d.getDay();

		var eventsData = navigatorCore.navItemFLayer.eventsDataByDay[day];
		//console.log("eventData.eventsData" + JSON.stringify(eventsData))
		for (var i = 0; i < eventsData.length; i++) {
			var eventData = eventsData[i];
			//console.log("eventData.location_id" +eventData.location_id  + " " +eventData.start_time + '>' +eventData.start_time_sec)
			var itemData = navigatorCore.navItemFLayer.boundItemsData[eventData.location_id];
			
			if (itemData) {
				var item_div = jQuery('<div/>', {
						//	href : '#',
						class : "list-group-item",
						//	onclick : "selectItem()",

					}).appendTo(div);

				item_div.attr('target-id', itemData.id);

				var div_img_cont = jQuery('<div/>', {
						//	href : '#',
						class : "item-list-img-cont",
						//	onclick : "selectItem()",

					}).appendTo(item_div);

				var img = jQuery('<img/>', {
						class : "pull-left item-list-img",
						src : itemData['popupPreviewURL']
					}).appendTo(div_img_cont);

				var distanceTo = navigatorCore.findDistanceToItemM(itemData['id']);

				var span = jQuery('<span/>', {
						class : "label label-success label-pill",
						text : distanceTo
					}).appendTo(div_img_cont)

					var div_pr_cont = jQuery('<div/>', {
						//	href : '#',
						class : "item-list-pr-cont",
						//	onclick : "selectItem()",

					}).appendTo(item_div);

				var h4 = jQuery('<h4/>', {
						class : "list-group-item-heading",
						text : eventData['name'],
					}).appendTo(div_pr_cont);

				var nextEvent = eventData;
				if (nextEvent) {
					var info = jQuery('<span/>', {
							class : "item-list-event-info",
						}).appendTo(div_pr_cont);

					var span1 = jQuery('<span/>', {
							class : "item-list-event-type",
							text : nextEvent.type + ':'
						}).appendTo(info);

					var timeTo = displayTimeFromSecondsToHoursAndMinutes(nextEvent.start_time_sec - getSecondsFromDayStart(new Date()))
						//console.log('timeTo ' + timeTo);
						if (timeTo)
							var span2 = jQuery('<span/>', {
									class : "item-list-event-timeto",
									text : "in " + timeTo
								}).appendTo(info);

						var span3 = jQuery('<span/>', {
							class : "item-list-event-time",
							text : nextEvent.start_time
						}).appendTo(info);

					var span4 = jQuery('<span/>', {
							class : "item-list-event-status",
							text : nextEvent.status
						}).appendTo(info);

					if (nextEvent.status == 'open')
						span4.addClass('event-open')

						if (nextEvent.status == 'closed')
							span4.addClass('event-closed')

				}

				var a_dir = jQuery('<a/>', {
						href : '#',
						class : "item-list-get-directions-link",
						onclick : "getDirections(event)",
						text : langString (language, 'directions')
					}).appendTo(div_pr_cont);

				a_dir.attr('target-id', itemData['id']);
			}
		}

	})
}

function getDirections(e) {
	//alert('getDirections'+e );
	var target_id = e.target.getAttribute('target-id');
	if (target_id) {
		//console.log('You selected: ' + target_id);
		navigatorCore.getDirectionsForTargetItem(target_id);
		if (navigatorCore.navPathAssistant.isActive) {
			dismissEye();
			$("#navigation_overlay").show();
				popup.hide();
				$("#item-details-modal-sm .close").click();
				$("#trailItems .close").click();
				$("#trailEvents .close").click();
				$("#trailItemsSearch .close").click();
				if (navigatorCore.locationManager.getLastKnownLocation())
				map.getView().setCenter(navigatorCore.locationManager.getLastKnownLocation());
		}
	}


}
function createMapPoupHTML(itemID) {

	var itemData = navigatorCore.navItemFLayer.boundItemsData[itemID];

	var div = jQuery('<div/>', {})




	var a = jQuery('<div/>', {
			//id : 'foo',
			//href : '#',
			id : "item-map-popup-link",
			class : "item-map-popup-link"
		}).appendTo(div);
		
	
		
		
	//a.attr('target-id', itemID);

	var divImg = jQuery('<div/>', {
			href : '#',
			id : "item-map-popup-img",
			class : "item-map-popup-img"
		}).appendTo(a);

	var img = jQuery('<img/>', {
			id : "item-map-popup-img-img",
			class : "item-map-popup-img-img",
			src : itemData['popupPreviewURL']
		}).appendTo(divImg);
		
		
		
	var divTitleBar = jQuery('<div/>', {
			href : '#',
			id : "item-map-popup-title-bar",
			class : "item-map-popup-title-bar"
	}).appendTo(div);


	var span = jQuery('<span/>', {
			id : "item-map-popup-text",
			class : "item-map-popup-text",
			text : itemData['popupHeading']
		}).appendTo(divTitleBar);





	jQuery('<br/>', {}).appendTo(span);
	

	var span_bottom_toolbar = jQuery('<span/>', {
			id : "item-map-popup-bottom-toolbar",
			class : "item-map-popup-bottom-toolbar"
	}).appendTo(div);
	
		var span = jQuery('<span/>', {
			id : "item-map-popup-hits-text",
			class : "item-map-hits-text",
			text : "Value: " + itemData['count']
		}).appendTo(span_bottom_toolbar);




	return div.html();
}

function dismissEye() {
	
}
function selectItem() {
	$('#trailItems').modal('toggle');
	$("#main_bar").hide();
	$("#navigation_overlay").show();
	$("#selection_overlay").show();
	$("#selection_overlay").show();

}

function selectItemSearch() {
	$('#trailItemsSearch').modal('toggle');
	$("#main_bar").hide();
	$("#navigation_overlay").show();
	$("#selection_overlay").show();

}
//generateTestEventData();




function initDebugConsole(enable) {

	$("#js_console").hide();
if(enable){
	$("#js_console").show();
	console.log = debugLog;
	window.console.errors = debugLog;
	window.console.info = debugLog;
	window.console.warn = debugLog;
	window.onerror = debugLog;
	}


}

function debugLog(message, source, lineno, colno, error) {
	var log = document.getElementById('js_console');

	var p = document.createElement('p');
	p.textContent = ''
		if (message)
			p.textContent += message;
		if (source)
			p.textContent += " source: " + source;
		if (lineno)
			p.textContent += " line: " + lineno;
		if (colno)
			p.textContent += " col: " + colno;
		if (error)
			p.textContent += " error:" + error;
		if (error)
			p.textContent += " error:" + error;
		//	if(error && error.stack) p.textContent+=" error stack:"+ error.stack;

		log.prependChild(p);
}

Element.prototype.prependChild = function (child) {
	this.insertBefore(child, this.firstChild);
};

function searchByTerm() {
	var searchTerm = $("#searchTerm").val();

//	if(searchTerm){
	//	var searchResults = navigatorCore.navItemFLayer.searchByTerm(searchTerm);
		//console.log(JSON.stringify(searchResults));
	//	displaySearchResults(searchResults);
	//}
	
	var searchResults = navigatorCore.navItemFLayer.searchByType(this.searchByTypeCache,true,searchTerm);
	displaySearchResults(searchResults);
	
}

function searchByType(type,strict) {
	$('#search_options').hide()
	$('#keyword_search').show()
	$("#searchTerm").val('');
	this.searchByTypeCache=type;
	
	var searchResults = navigatorCore.navItemFLayer.searchByType(type,strict);
	//console.log(JSON.stringify(searchResults));
	displaySearchResults(searchResults);
}



this.searchByTypeCache;


function searchByTypeEvents(type) {
	$('#search_options').show()
	$('#keyword_search').hide()
}

function resetSearch() {
		$('#search_options').show()
	    $('#keyword_search').hide()
		var modal = $('#trailItemsSearch')
		var div = modal.find('#items-list-display');
		$(div).empty();
}

function displaySearchResults(searchResults)
{
	var modal = $('#trailItemsSearch')
	var cont_div = modal.find('#items-list-display');
	$(cont_div).empty();
	
	
	var count_div = jQuery('<div/>', {
		text: "Found " + searchResults.items.length + " item(s)",
		class: "search-results-title"
	}).appendTo(cont_div);
	
	var div = jQuery('<div/>', {
		class: "results-list",
		id: "results-list"
	}).appendTo(cont_div);
	

//	var br_div = jQuery('<br/>', {}).appendTo(div);

	for (var key in searchResults.items) {
		var itemData = searchResults.items[key];

		var item_div = jQuery('<div/>', {
				//	href : '#',
				class : "search-results-item",
				//	onclick : "selectItem()",

			}).appendTo(div);

		item_div.attr('target-id', itemData.id);

		var div_img_cont = jQuery('<div/>', {
					//	href : '#',
					class : "item-list-img-cont",
					//	onclick : "selectItem()",

				}).appendTo(item_div);
				
       var image_cont =div_img_cont;


				
			var img = jQuery('<img/>', {
					class : "pull-left item-list-img",
					src : itemData['popupPreviewURL']
				}).appendTo(image_cont);

	
				var div_pr_cont = jQuery('<div/>', {
					//	href : '#',
					class : "item-list-pr-cont",
					//	onclick : "selectItem()",

				}).appendTo(item_div);

				
					
				var divTitleBar = jQuery('<div/>', {
						href : '#',
						id : "item-map-search-title-bar",
						class : "item-map-search-title-bar"
				}).appendTo(item_div);


				var span = jQuery('<span/>', {
						id : "item-map-popup-text",
						class : "item-map-search-text",
						text : itemData['popupHeading']
					}).appendTo(divTitleBar);



			
		var span_bottom_toolbar = jQuery('<span/>', {
				id : "item-map-search-bottom-toolbar",
				class : "item-map-search-bottom-toolbar"
		}).appendTo(item_div);
		
		
		var span = jQuery('<span/>', {
			id : "item-map-search-text",
			class : "item-map-hits-text",
			text : "Value: " + itemData['count']
		}).appendTo(span_bottom_toolbar);
		

		
	
		var a_dir = jQuery('<a/>', {
					href : '#',
					class : "item-list-get-directions-link",
					onclick : "showOnMap(event)",
					text : 'Show on map'
				}).appendTo(span_bottom_toolbar);

			a_dir.attr('target-id', itemData['id']);
			


		}

	
}




function findOnMap(){
	navigatorCore.navPathAssistant.stopNavigationAssistance();
	$("#navigation_overlay").hide();
	dismissEye();
	popup.hide();
	$("#item-details-modal-sm .close").click();
	resetSearch();
    if ($('#trailItemsSearch').css('display') == 'none') {
        $("#btnSearch").click();
		//$('#keyword_search').hide()
    }else{

	}

    //$("#trailItemsSearch .close").click();
	
	//$("#btnSearch").click();
	

}

function showOnMap(location_id){
	navigatorCore.navPathAssistant.stopNavigationAssistance();
	$("#navigation_overlay").hide();
	dismissEye();
	popup.hide();
	$("#item-details-modal-sm .close").click();
	$("#trailItemsSearch .close").click();

	var itemData = navigatorCore.navItemFLayer.boundItemsData_Location[location_id];
	var feature = itemData['feature']
	if (feature && feature.get("type") == "marker-with-popup") {
			insureTypeVisible(itemData.marker_type);
			//console.log(feature.get("type"));
			var coord = feature.getGeometry().getCoordinates();
			var props = feature.getProperties();
			//console.log('You popup_content: ' + feature.get('popup_content'));
			popup.show(coord, createMapPoupHTML(feature.getId()));
			map.getView().setCenter(feature.getGeometry().getCoordinates());
		}

}

function showOnMap(e){
	var target_id = e.target.getAttribute('target-id');
//	navigatorCore.navPathAssistant.stopNavigationAssistance();
	$("#navigation_overlay").hide();
	dismissEye();
	popup.hide();
	$("#item-details-modal-sm .close").click();
	$("#trailItemsSearch .close").click();

	var itemData = navigatorCore.navItemFLayer.boundItemsData[target_id];
	var feature = itemData['feature']
	if (feature && feature.get("type") == "marker-with-popup") {
			insureTypeVisible(itemData.marker_type);
			//console.log(feature.get("type"));
			var coord = feature.getGeometry().getCoordinates();
			var props = feature.getProperties();
			//console.log('You popup_content: ' + feature.get('popup_content'));
			popup.show(coord, createMapPoupHTML(feature.getId()));
			map.getView().setCenter(feature.getGeometry().getCoordinates());
		}

}




function insureTypeVisible(marker_type) {
	var togglesArray = searchOptionsTypeLookupDic[marker_type]
		if (togglesArray) {
			//console.log(JSON.stringify(togglesArray));
			for (var keyT in togglesArray) {
				var toggleID = '#' + togglesArray[keyT];
				if ($(toggleID).attr('checked') != 'checked')
					$(toggleID).click()
			}
		}

}
		
function showStaticMarkerOnMap(marker_id){
	navigatorCore.navPathAssistant.stopNavigationAssistance();
	$("#navigation_overlay").hide();
	dismissEye();
	popup.hide();
	$("#item-details-modal-sm .close").click();
	$("#trailItemsSearch .close").click();	
	var itemData = navigatorCore.navItemFLayer.boundItemsData[marker_id];
	var feature = itemData['feature']
	if (feature ) {
		insureTypeVisible(itemData.marker_type);
		
		var coord = feature.getGeometry().getCoordinates();
		var props = feature.getProperties();

		popup.show(coord, createMapPoupHTML(feature.getId()));
		map.getView().setCenter(feature.getGeometry().getCoordinates());
	}

}

var searchOptionsDefDic = {};
var searchOptionsTypeLookupDic = {};

function initFilterOptions() {

	
	$("#searchTerm").on('input', function(){
      searchByTerm();
});


	var populated_types = {}

	var boundItemsData = navigatorCore.navItemFLayer.boundItemsData;
	for (var key in boundItemsData) {
		var itemData = boundItemsData[key];
		if (itemData.feature) {
			populated_types[itemData.marker_type] = "1"
		}
	}
	// create structure
	var search_options = $("#search_options")

		for (var key in searchOptionsDef) {
			var searchOption = searchOptionsDef[key];
			searchOptionsDefDic[searchOption.id] = searchOption;
			
			var searchOptionRow = jQuery('<div/>', {
					//id : 'foo',
					//href : '#',
					id : searchOption.id + "-row",
					class : 'row'
				}).appendTo(search_options);

			var col1 = jQuery('<div/>', {
					class : 'col-xs-9'
				}).appendTo(searchOptionRow);

			var buttonSearch = jQuery('<button/>', {
					id : searchOption.id + "-toggle-button",
					class : 'btn btn-default btn-search',
					target_id : key,
				}).appendTo(col1);

			var img = jQuery('<img/>', {
					src : searchOption.icon,
					class : 'img-search-option',
				}).appendTo(buttonSearch);

			buttonSearch.append(searchOption.name);

			buttonSearch.bind("click", function (event, ui) {
				var targer_id = $(event.target).attr('target_id');
				//	console.log(event.target);
				//	console.log(targer_id);
				searchByType(searchOptionsDef[targer_id].types, false);

			});

			var col2 = jQuery('<div/>', {
					class : 'col-xs-3'
				}).appendTo(searchOptionRow);

			toggle = jQuery('<input/>', {
					id : searchOption.id + "-toggle",
					type : 'checkbox',
					class : "toggle",
					checked : "checked",
					target_id : key,
				}).appendTo(col2);
			toggle.bind("change", function (event, ui) {
				var targer_id = $(event.target).attr('target_id');
				//console.log(event.target);
				//console.log(targer_id);
				toggleMarkers(searchOptionsDef[targer_id].id, this.checked);
			});

			if (searchOption.disabled == true) {
				toggleMarkers(searchOption.id, false);
			}

		}

		for (var key in searchOptionsDef) {
			var searchOption = searchOptionsDef[key];
			var toggleEl = document.getElementById(searchOption.id + "-toggle")
			new Switchery(toggleEl);
			var hasItems = false;
			for (var keyT in searchOption.types) {
				var type = searchOption.types[keyT]
					//console.log('type: ' + type)
					//console.log('hasItems: ' + hasItems)
					if(!hasItems) hasItems = populated_types[type];
					var togglesArray = searchOptionsTypeLookupDic[type]
					if(!togglesArray) {
						togglesArray = [];
						searchOptionsTypeLookupDic[type]=togglesArray
					}
					togglesArray.push(searchOption.id + "-toggle");
			}

			if (!hasItems) {
				//console.log('disable: '+key)
				var containerID = '#' + searchOption.id + '-row';
				$(containerID).hide();
			}
		}

		//appConnector.showOnMap('199');
}

var disabledTypes = {}
function toggleMarkers(id, show) {
	//console.log("name " + name);
	//console.log("show " + show);
	dismissEye();
	var containerID = '#' + id + '-toggle-row';
	var buttonID = '#' + id + '-toggle-button';
	var toggleID = '#' + id + '-toggle';
	
	var searchOption = searchOptionsDefDic[id]
		for (var keyT in searchOption.types) {
			var type = searchOption.types[keyT]
				//console.log('type: ' + type)
			if(show)	
			disabledTypes[type]=undefined;	
			else 
			disabledTypes[type]=true;

		}
	//console.log("$(toggleID).attr('checked') " + $(toggleID).attr('checked'));
	if (show && $(toggleID).attr('checked') == 'checked')
		return;

	if (show) {

		$(containerID).removeClass('disabled');
		$(buttonID).prop("disabled", false);
		$(toggleID).attr('checked', 'checked');
		
	} else {
		$(containerID).addClass('disabled');
		$(buttonID).prop("disabled", true);
		$(toggleID).attr('checked', null);
	}

	var searchOption = searchOptionsDefDic[id]
		for (var keyT in searchOption.types) {
			var type = searchOption.types[keyT]
				//console.log('type: ' + type)
				var boundItemsData = navigatorCore.navItemFLayer.boundItemsData;
			for (var key in boundItemsData) {
				var itemData = boundItemsData[key];
				if (itemData.feature && itemData.marker_type == type) {
					if (show){
						itemData.feature.getStyle().getImage().setOpacity('1');
						//itemData.hm_feature.getStyle().getImage().setOpacity('1');
						if(!itemData['hm_added'] ){
							vectorSourceHeatMap.addFeature(itemData.hm_feature);
							itemData['hm_added'] =true;
						}

					}
					else {
						itemData.feature.getStyle().getImage().setOpacity('0');
						//itemData.hm_feature.getStyle().getImage().setOpacity('0');
						if(itemData['hm_added'] ){
					    vectorSourceHeatMap.removeFeature(itemData.hm_feature);		
						itemData['hm_added'] =false;
						}						
					}
					itemData.feature.changed();
					
				}
			}
		}
		if (searchOption.linked_labels) {
			navigatorCore.vectorLabels.getSource().forEachFeature(
				function (feature) {
				var type = feature.get('type');
				// var isNav=feature.getId()&& feature.getId().indexOf('temp')==-1;
				// console.log("feature= " + type +' '+ feature.getId());
				if (type == "img-label") {
					if (!show)
						feature.set('hide','true')
					else
						feature.set('hide',undefined)
						//feature.getStyle().getImage().setOpacity('0');
				  	feature.changed();

				}

			})

		}
}
function canBeAddedToMyDay(markerType){
	return addToMyDayOptions[markerType] && addToMyDayOptions[markerType]==true;
}



// heatmap
