var bindLinkEditor;
var select_interaction, draw_interaction, modify_interaction;
var $geom_type;
var $interaction_type;
var $draw_controls;
var vector_layer;
var vectorSource;


var selectedIconMarkerStyle = new ol.style.Style({
		image : new ol.style.Icon(/** @type {olx.style.IconOptions} */
			({
				anchor : [0.5, 41],
				anchorXUnits : 'fraction',
				anchorYUnits : 'pixels',
				src : './assets/marker_icons/general_r.png'
			}))
	});
	
var iconMarkerStyle = new ol.style.Style({
		image : new ol.style.Icon(/** @type {olx.style.IconOptions} */
			({
				anchor : [0.5, 41],
				anchorXUnits : 'fraction',
				anchorYUnits : 'pixels',
				src : './assets/marker_icons/general.png'
			}))
	});	
	
	
var polygonStyle = new ol.style.Style({
		stroke : new ol.style.Stroke({
			color : 'rgba(0, 0, 255, 1)',
			width : 1

		}),
		fill : new ol.style.Fill({
			color : 'rgba(0, 0, 255, 0.1)'
		})
	});	
	

function initLabelEditor() {
	showLabelBoxOutline =true;
	vectorSource = new ol.source.Vector();

	vector_layer = new ol.layer.Vector({
			name : 'labels',
			source : vectorSource,
			style : labelStyle()
		});

	map.addLayer(vector_layer);

	bindLinkEditor = new BindLinkEditor(map, vector_layer);
	
	var labelsJSON = serverConnector.getLabelsJSON();
	if (labelsJSON)
			loadLabelsLayer(labelsJSON,vectorSource);

	$geom_type = $('#geom_type');
	$interaction_type = $('[name="interaction_type"]');
	$draw_controls = $('[id="draw_controls"]');

	$geom_type.on('change', function (e) {
		updateForDraw();
	});

	initForDraw();

	// rebuild interaction when changed
	$interaction_type.on('click', function (e) {
		// add new interaction
		if (this.value === 'draw') {
			initForDraw();
		} else if (this.value === 'modify') {
			initForModify();
		} else if (this.value === 'link') {
			initForLink();
		}
	});
	
   // load label icon options
	var labelImageURL = $("#labelImageURL");
	$.each(labelIcons, function (item) {
		var labelIcon = labelIcons[item];
		labelImageURL.append($("<option />").val(labelIcon).text(labelIcon));
	});
	
	$("#labelImageURL").bind('change', function(e) {
	$("#labelImage").attr('src',$("#labelImageURL").val());  
	});

	$("#lang").bind('change', function(e) {
		if(selectedfeature)
	selectFeatureForPropertiesEdit(selectedfeature)
	});


//	map.on('pointermove', function (evt) {
		
	//});

	//map.on('click', function (evt) {

//	});
	//preloadLabels();
}

function initForDraw() {
	////console.log("initForDraw");
	resetPropertiesEditStyle();
	$(document).off('keyup');
	$draw_controls.show();
	map.removeInteraction(select_interaction);
	map.removeInteraction(modify_interaction);
	map.removeInteraction(draw_interaction);

	addSelectInteraction();
	addDrawInteraction();
	addConnectionMode = false;
	bindLinkEditor.unregisterCreateLinkEvents();
	resetSelectedFeaturePropertiesDisplay();
}
function updateForDraw() {
	////console.log("updateForDraw");
	resetPropertiesEditStyle();
	$(document).off('keyup');
	map.removeInteraction(draw_interaction);
	addDrawInteraction();
	addConnectionMode = false;
	resetSelectedFeaturePropertiesDisplay();
}

function initForModify() {
	$(document).off('keyup');
	$draw_controls.hide();
	map.removeInteraction(select_interaction);
	map.removeInteraction(draw_interaction);
	map.removeInteraction(modify_interaction);
	addSelectInteraction();
	addModifyInteraction();
	addConnectionMode = false;

	resetSelectedFeaturePropertiesDisplay();
	bindLinkEditor.unregisterCreateLinkEvents();

}

function initForLink() {
	$(document).off('keyup');
	$draw_controls.hide();

	map.removeInteraction(select_interaction);
	map.removeInteraction(modify_interaction);
	map.removeInteraction(draw_interaction);
	addConnectionMode = true;
	resetSelectedFeaturePropertiesDisplay();
	bindLinkEditor.registerCreateLinkEvents();
}

// build up modify interaction
// needs a select and a modify interaction working together


function addSelectInteraction() {

	// remove draw interaction
	// create select interaction
	select_interaction = new ol.interaction.Select({
			// make sure only the desired layer can be selected
			layers : function (vector_layer) {
				return vector_layer.get('name') === 'labels';
			},
			filter : function (feature, layer) {
				//console.log("filter: " + feature.get("type"));
				if (feature.get("type") == "img-label" || feature.get("type") == "text-label"|| feature.get("type") == "text-label-line")
					return feature;
				else
					return null;
			},
			style: labelStyle(),
		});
	select_interaction.on('select', select);
	map.addInteraction(select_interaction);
	var selected_features = select_interaction.getFeatures();

}

function deleteItem(selected_feature, select_interaction) {
	var selected_features = select_interaction.getFeatures();
	selected_features.remove(selected_feature);
	vector_layer.getSource().removeFeature(selected_feature);
	resetSelectedFeaturePropertiesDisplay();
	bindLinkEditor.updateLinksOnDelete(selected_feature);
}

function addModifyInteraction() {

	var selected_features = select_interaction.getFeatures();

	// create the modify interaction
	modify_interaction = new ol.interaction.Modify({

			features : selected_features,
			// delete vertices by pressing the SHIFT key
			deleteCondition : function (event) {
				return ol.events.condition.shiftKeyOnly(event) &&
				ol.events.condition.singleClick(event);
			}
		});
	// add it to the map
	map.addInteraction(modify_interaction);
	modify_interaction.on('modifystart', modifystart);
	modify_interaction.on('modifyend', modifyend, null);
	//  modify_interaction.on('propertychange', propertychange,null);
	//  modify_interaction.on('change', change,null);

}

function select(evt) {
	////console.log("select_interaction: select=" + evt.selected);
	resetPropertiesEditStyle();
	var feature = evt.selected[0];
	if (feature) {
		if (feature.get("type") == "img-label" || feature.get("type") == "text-label"|| feature.get("type") == "text-label-line") {
			selectFeatureForPropertiesEdit(evt.selected[0]);

		} else if (feature.get("type") == "nav-node") {
			//alert("nav node selected");
		}

	}

}

function modifyend(evt) {
	// //console.log("modifyend");
	//var coord = selectedfeature.getGeometry().getCoordinates();
	//selectedfeature.getGeometry().setCoordinates([coord[0],coord[coord.length-1]])
	updateSelectedFeatureCoordinates();
	bindLinkEditor.updateLinkPositionOnModifyEnd(evt);

}

function modifystart(evt) {}

// creates a draw interaction
function addDrawInteraction() {
	// remove other interactions
	////console.log("addDrawInteraction");

	var value = $geom_type.val();
	if (value !== 'None') {
		var geometryFunction,
		maxPoints;
		if (value === 'Square') {
			value = 'Circle';
			geometryFunction = ol.interaction.Draw.createRegularPolygon(4);
		} else if (value === 'Box') {
			value = 'LineString';
			maxPoints = 2;
			geometryFunction = function (coordinates, geometry) {
				if (!geometry) {
					geometry = new ol.geom.Polygon(null);
				}
				var start = coordinates[0];
				var end = coordinates[1];
				geometry.setCoordinates([
						[start, [start[0], end[1]], end, [end[0], start[1]], start]
					]);
				return geometry;
			};
		}
		draw_interaction = new ol.interaction.Draw({
				source : vector_layer.getSource(),
				type : /** @type {ol.geom.GeometryType} */
				(value),
				geometryFunction : geometryFunction,
				maxPoints : maxPoints
			});

	}

	// add it to the map
	map.addInteraction(draw_interaction);

	draw_interaction.on('drawend', function (event) {
		
		// create a unique id
		
		var id = uid("L");
		event.feature.setId(id);

		event.feature.set('gType', $geom_type.val());

		var value = $geom_type.val();


		if (value == "Square") {
			event.feature.set('type', "text-label");
			//	event.feature.setStyle(polygonStyle);
		}

		if (value == "Box") {
			event.feature.set('type', "text-label");
			//	event.feature.setStyle(polygonStyle);
		}
		if (value == "Circle") {
			event.feature.set('type', "text-label");

			//	event.feature.setStyle(polygonStyle);
		}
		if (value == "Polygon") {
			event.feature.set('type', "text-label");
			//	event.feature.setStyle(polygonStyle);
		}

		if (value == "LineString") {
			event.feature.set('type', "text-label-line");
				console.log("creating style= " + 'text-label-text');
			//	event.feature.setStyle(polygonStyle);
			var coord = event.feature.getGeometry().getCoordinates();
			event.feature.getGeometry().setCoordinates([coord[0],coord[coord.length-1]])

		}
		
		if ($geom_type.val() == "Point") {

			event.feature.set('type', "img-label");
		//	event.feature.setStyle(iconMarkerStyle);
		

			polygon = isInsidePolygon(event.feature.getGeometry().getCoordinates());

			if (polygon) {
				////console.log('polygon' + polygon);
			}

		}

	});

}





function isInsidePolygon(coord) {
	var pixel = map.getPixelFromCoordinate(coord);
	////console.log('pixel' + pixel);
	var feature = map.forEachFeatureAtPixel(pixel,
			function (feature) {
			if (feature.get("type") == "Polygon")
				return feature;
			else
				return null;
		});

	return feature;

}

function onPointerDown(evt) {
	////console.log('map:onPointerDown');

}
function onPointerUp(evt) {
	////console.log('map:onPointerUp');

}


var savedData;

function saveData() {
	var dataToSave = {};

	var features = vector_layer.getSource().getFeatures();
	for (var i = 0; i < features.length; i++) {
		var feature = features[i];

		if (feature.get("type") == "text-label" || feature.get("type") == "text-label-line" ) {
			//console.log('found polygon: ' + feature.getId());
			var polygonData = {};
			var id = feature.getId();
			polygonData['gType'] = feature.get('gType');
			polygonData['type'] = feature.get('type');
			polygonData['id'] = feature.getId();
			polygonData['coord'] = feature.getGeometry().getCoordinates();
			polygonData['label'] = feature.get('label');
			polygonData['labelIntl'] = feature.get('labelIntl');
			polygonData['color'] = feature.get('color');
			polygonData['color_f'] = feature.get('color_f');
			polygonData['popupPreviewURL'] = feature.get('popupPreviewURL');

			
			var s = feature.get('popupHeading')
			polygonData['popupHeading'] = feature.get('popupHeading')

			
			
			polygonData['popupText'] = feature.get('popupText');
			// get points
			var pointLinksData = {};
			if (feature['links-bbn']) {
				for (var l = 0; l < feature['links-bbn'].length; l++) {
					var linkData = {};
					var link = feature['links-bbn'][l];
					var destinationPoint;
					destinationPoint = link['endFeature'];
					if (destinationPoint.get("type") == "nav-node") {
						linkData["type"] = "link-bbn";
						linkData["destNode"] = destinationPoint.getId();

					} else if (destinationPoint.get("type") == "connect-node-bbl") {
						var hostLink = destinationPoint['hostLink'];
						var startNode = hostLink['startPoint'];
						var endNode = hostLink['endPoint'];

						linkData["type"] = "connect-node-bbl"
							//linkData["hostLink"] = hostLink.getId();
							//	//console.log('startNode ' + startNode.get("type"));

							linkData["startPoint"] = startNode['id'];
						linkData["endPoint"] = endNode['id'];
						linkData["hostLink"] = hostLink.getId();
						linkData["coord"] = destinationPoint.getGeometry().getCoordinates();
					}

					pointLinksData[destinationPoint.getId()] = linkData;
				}
				polygonData['links-bbn'] = pointLinksData;
			}
			dataToSave[id] = polygonData;
		}
		////console.log('found point: ' + feature.get("type"));
		if (feature.get("type") == "img-label") {
			//	//console.log('found point: ' + feature.getId());
			var pointData = {};
			var id = feature.getId();
			var label = feature.get('name');

			pointData['type'] = feature.get('type');
			pointData['gType'] = feature.get('gType');
			pointData['id'] = feature.getId();
			
			pointData['coord'] = feature.getGeometry().getCoordinates();
			pointData['label'] = feature.get('label');
			pointData['labelIntl'] = feature.get('labelIntl');
			pointData['labelImageURL'] = feature.get('labelImageURL');
			pointData['labelImageScale'] = feature.get('labelImageScale');
			pointData['marker_type'] = feature.get('marker_type');
			pointData['popupPreviewURL'] = feature.get('popupPreviewURL');
			pointData['popupHeading'] = feature.get('popupHeading');
			pointData['popupText'] = feature.get('popupText');

			// get points
			var pointLinksData = {};
			if (feature['links-bbn']) {
				for (var l = 0; l < feature['links-bbn'].length; l++) {
					var linkData = {};
					var link = feature['links-bbn'][l];
					var destinationPoint;
					destinationPoint = link['endFeature'];
					if (destinationPoint.get("type") == "nav-node") {
						linkData["type"] = "link-bbn";
						linkData["destNode"] = destinationPoint.getId();

					} else if (destinationPoint.get("type") == "connect-node-bbl") {
						var hostLink = destinationPoint['hostLink'];
						var startNode = hostLink['startPoint'];
						var endNode = hostLink['endPoint'];

						linkData["type"] = "connect-node-bbl"
							linkData["hostLink"] = hostLink.getId();
						////console.log('startNode ' + startNode.get("type"));
						linkData["hostLink"] = hostLink.getId();
						linkData["startPoint"] = startNode.getId();
						linkData["endPoint"] = endNode.getId();
						linkData["coord"] = destinationPoint.getGeometry().getCoordinates();
					}

					pointLinksData[destinationPoint.getId()] = linkData;
				}
				pointData['links-bbn'] = pointLinksData;
			}

			dataToSave[id] = pointData;
		}
	}

	var s = JSON.stringify(dataToSave);
	$('#data').val(s);
	savedData = s;
	serverConnector.saveData("labels_json",s);

}

function loadData() {
	var s = $('#data').val();
	////console.log('load: '+s );
	removeAllFeatures();
	loadLabelsLayer(s);

}

function downloadData() {
	if(savedData){
		download("labels_json.js", 'localData_labels_json = ' + "'" + savedData + "'");
	}
}

function removeAllFeatures() {
var features = vector_layer.getSource().getFeatures();
	for (var i = 0; i < features.length; i++) {
	     vectorSource.removeFeature(features[i])
	}

}

function loadLabelsLayer(s) {
	//console.log('load: ' + s);
	var boundItemsData = s;
	if (typeof s === 'string')
		boundItemsData= JSON.parse(s);
	for (var key in boundItemsData) {
		var itemData = boundItemsData[key];
		deserialiseItem(itemData);
	}

}

function deserialiseItem(itemData) {
	if (itemData['type'] == 'img-label') {
	//	//console.log('loadPoint ');
		var point = new ol.geom.Point(itemData['coord']);
		var nodeFeature =
			new ol.Feature({
				id : itemData['id'],
				type : 'img-label',
				geometry : point,

			});
		//itemData['labelIntl']={};
		//itemData['labelIntl']['en'] = itemData['label']
	//	itemData['labelIntl']['zh_Hans'] = itemData['label'] + ' ChHans'	
		
		
		nodeFeature.setId(itemData['id']);
		nodeFeature.set('gType', itemData['gType']);
		nodeFeature.set('popupPreviewURL', itemData['popupPreviewURL']);
		nodeFeature.set('popupHeading', itemData['popupHeading']);
		nodeFeature.set('popupText', itemData['popupText']);
		nodeFeature.set('labelImageURL', itemData['labelImageURL']);
		nodeFeature.set('labelImageScale', itemData['labelImageScale']);
		//nodeFeature.setStyle(iconMarkerStyle);
		vectorSource.addFeature(nodeFeature);
		
		nodeFeature.set('label', itemData['label']);
		nodeFeature.set('labelIntl', itemData['labelIntl']);
		// expand bindings

		var links_bbn = itemData['links-bbn'];
		if (links_bbn)
			bindLinkEditor.expandBindingsForPoint(nodeFeature, links_bbn);

	} else if (itemData['type'] == 'text-label') {

		////console.log('load Polygon ');
		var polygon = new ol.geom.Polygon(itemData['coord']);
		var nodeFeature =
			new ol.Feature({
				id : itemData['id'],
				type : 'text-label',
				geometry : polygon

			});
		nodeFeature.set('label', itemData['label']);
		nodeFeature.set('labelIntl', itemData['labelIntl']);
		nodeFeature.set('color', itemData['color']);
		nodeFeature.set('color_f', itemData['color_f']);
		nodeFeature.setId(itemData['id']);
		nodeFeature.set('gType', itemData['gType']);
		nodeFeature.set('popupPreviewURL', itemData['popupPreviewURL']);
		nodeFeature.set('popupHeading', itemData['popupHeading']);
		nodeFeature.set('popupText', itemData['popupText']);
		nodeFeature.set('labelImageURL', itemData['labelImageURL']);
		nodeFeature.set('labelImageScale', itemData['labelImageScale']);
		vectorSource.addFeature(nodeFeature);

		// expand bindings

		var links_bbn = itemData['links-bbn'];
		if (links_bbn)
			bindLinkEditor.expandBindingsForPolygon(nodeFeature, links_bbn);

	}
	else if (itemData['type'] == 'text-label-line') {

		////console.log('load Polygon ');
		var line = new ol.geom.LineString(itemData['coord']);
		var nodeFeature =
			new ol.Feature({
				id : itemData['id'],
				type : 'text-label-line',
				geometry : line,

			});
		nodeFeature.set('label', itemData['label']);
		nodeFeature.set('labelIntl', itemData['labelIntl']);
		nodeFeature.setId(itemData['id']);
		nodeFeature.set('gType', itemData['gType']);
		nodeFeature.set('popupPreviewURL', itemData['popupPreviewURL']);
		nodeFeature.set('popupHeading', itemData['popupHeading']);
		nodeFeature.set('popupText', itemData['popupText']);
		nodeFeature.set('labelImageURL', itemData['labelImageURL']);
		nodeFeature.set('labelImageScale', itemData['labelImageScale']);
		vectorSource.addFeature(nodeFeature);

		// expand bindings

		var links_bbn = itemData['links-bbn'];
		if (links_bbn)
			bindLinkEditor.expandBindingsForPolygon(nodeFeature, links_bbn);

	}
}

function download(filename, text) {
	var element = document.createElement('a');
	element.setAttribute('href', 'data:text/javascript;charset=utf-8,' + encodeURIComponent(text));
	element.setAttribute('download', filename);

	element.style.display = 'none';
	document.body.appendChild(element);

	element.click();

	document.body.removeChild(element);
}




function selectFeatureForPropertiesEdit(feature) {
	if (feature) {
		selectedfeature = feature;
		// //console.log("selectFeatureForPropertiesEdit"+feature.getId());
		if (feature.get("type") == "img-label") {
			//feature.setStyle(selectedIconMarkerStyle);
			$('#labelImageURL_c').show();
			$('#labelData_c').hide();
			$('#labelImage_c').show();
			$('#labelImageScale_c').show();
			
		} else {
			$('#labelImageURL_c').hide();
			$('#labelData_c').show();
			$('#labelImage_c').hide()
			$('#labelImageScale_c').hide();
		}

		$('#editData').show();

		var $selectedFeatureID = $('#selectedFeatureID');
		var $selectedFeatureCoord = $('#selectedFeatureCoord');
		var $marker_type = $('#marker_type');

		var $labelData = $('#labelData');
		var $colorData = $('#colorData');
		var $colorData_f = $('#colorData_f');
		var $popupPreviewURL = $('#popupPreviewURL');
		var $popupHeading = $('#popupHeading');
		var $popupText = $('#popupText');
		var $labelImage = $('#labelImage');
		var $labelImageScale = $('#labelImageScale');
		
		$selectedFeatureID.val(selectedfeature.getId());
		//if (feature.getGeometry().getType() == 'Circle')
		//	$selectedFeatureCoord.val(JSON.stringify(selectedfeature.getGeometry().getCenter()))
		//else
		$selectedFeatureCoord.val(JSON.stringify(selectedfeature.getGeometry().getCoordinates()))
				if (selectedfeature.get('marker_type'))
					$marker_type.val(selectedfeature.get('marker_type'));
		
		var $lang =$('#lang');
		
		var langKey=$lang.val();
	   // console.log("langKey: " + langKey);
		$labelData.val(null);
		
		if($lang && langKey ){
			var labelDataIntl = selectedfeature.get('labelIntl') 
			if(labelDataIntl) $labelData.val(labelDataIntl[langKey]);  
		
			 
		 } else {		 
			$labelData.val(selectedfeature.get('label')); 

		 }
		
		
		
		
		$colorData.val(selectedfeature.get('color'));
		$colorData_f.val(selectedfeature.get('color_f'));
		$popupPreviewURL.val(selectedfeature.get('popupPreviewURL'));
		$popupHeading.val(selectedfeature.get('popupHeading'));
		$popupText.val(selectedfeature.get('popupText'));

		var $labelImageURL = $('#labelImageURL');
		$labelImageURL.val('');
		if (selectedfeature.get('labelImageURL'))
			$("#labelImageURL").val(selectedfeature.get('labelImageURL'));
		if (selectedfeature.get('labelImageScale'))
			$("#labelImageScale").val(selectedfeature.get('labelImageScale'));
		 else $("#labelImageScale").val(undefined);
		if(selectedfeature.get('labelImageURL'))
			$labelImage.attr('src',selectedfeature.get('labelImageURL'));  
		else 
		 $labelImage.attr('src','');  
	}
}

function resetPropertiesEditStyle() {
	var features = vector_layer.getSource().getFeatures();
	for (var i = 0; i < features.length; i++) {
		var feature = features[i];
		if (feature.get("type") == "Point") {
		//	feature.setStyle(iconMarkerStyle);

		}
	}
}

function unselectFeatureForPropertiesEdit(feature) {}

function updateSelectedFeatureCoordinates() {
	var $selectedFeatureCoord = $('#selectedFeatureCoord');
	$selectedFeatureCoord.val(JSON.stringify(selectedfeature.getGeometry().getCoordinates()));

}

function resetSelectedFeaturePropertiesDisplay() {
	resetPropertiesEditStyle()
	selectedfeature = null;
	$('#editData').hide();
}

var selectedfeature;

function saveLabelDataClicked() {

	var $selectedFeatureCoord = $('#selectedFeatureCoord');
	var $marker_type = $('#marker_type');
	var $labelData = $('#labelData');
	var $colorData = $('#colorData');
	var $colorData_f = $('#colorData_f');
	var $popupPreviewURL = $('#popupPreviewURL');
	var $popupHeading = $('#popupHeading');
	var $popupText = $('#popupText');
	var $labelImageURL = $('#labelImageURL');
	var $labelImage = $('#labelImage');
    var $labelImageScale = $('#labelImageScale');
	
	if ($labelImageURL.val()) {
		selectedfeature.set('labelImageURL', $labelImageURL.val());
		
	}
	//if ($labelImageScale.val()) {
		selectedfeature.set('labelImageScale', $labelImageScale.val());
		
	//}
	// var element = document.getElementById('labelData');
	//if (selectedfeature.getGeometry().getType() == 'Circle')
		//$selectedFeatureCoord.val(JSON.stringify(selectedfeature.getGeometry().setCenter(JSON.parse($selectedFeatureCoord.val()))))
	selectedfeature.getGeometry().setCoordinates(JSON.parse($selectedFeatureCoord.val()));
//console.log(JSON.parse($selectedFeatureCoord.val()));
	selectedfeature.set('marker_type', $marker_type.val());
	selectedfeature.set('name', $labelData.val());
	selectedfeature.set('popupPreviewURL', $popupPreviewURL.val());
	selectedfeature.set('popupHeading', $popupHeading.val());
	selectedfeature.set('popupText', $popupText.val());
		var $lang =$('#lang');
		
		var langKey=$lang.val();
	   // console.log("langKey: " + langKey);
		
		if($lang && langKey ){
			if(!selectedfeature.get('labelIntl')) selectedfeature.set('labelIntl',{}) 
			var labelDataIntl = selectedfeature.get('labelIntl') 
			labelDataIntl[langKey] = $labelData.val();
 
		 } else {		 
			selectedfeature.set('label', $labelData.val());
		 }

	selectedfeature.set('color', $colorData.val());
	selectedfeature.set('color_f', $colorData_f.val());
	vector_layer.getSource().removeFeature(selectedfeature);
	vector_layer.getSource().addFeature(selectedfeature);
	$labelImage.attr('src',selectedfeature.get('labelImageURL'));   
	 	selectedfeature.set('resetStyle','true');
	return false;
}

function deleteFeatureClicked() {
	deleteItem(selectedfeature, select_interaction);
}

$('a[data-toggle="tab"]').on('shown.bs.tab', function (e) {
	//console.log('showing tab ' + e.target); // Active Tab
	//console.log('showing tab ' + e.relatedTarget); // Previous Tab
})

$(document).on('shown.bs.tab', 'a[data-toggle="tab"]', function (e) {
	//var activatedTab = e.target; // activated tab
	//console.log('showing tab ' + e.target); // Active Tab
})

function preloadLabels(){
	var count=0;
	var stepx = (viewableBounds[2] - viewableBounds[0])/labelIcons.length
	var offsety =(viewableBounds[3] - viewableBounds[1])/10
	$.each(labelIcons, function (item) {
		count++;
		var coord = [viewableBounds[0]+stepx*count,mapCenter[1] ]
		//var coord = mapCenter;
			console.log('viewableBounds' + viewableBounds); // Active Tab
		console.log('coord' + coord); // Active Tab
		var labelIcon = labelIcons[item];
		console.log('labelIcon' + labelIcon); 
		var point = new ol.geom.Point(coord);
		var nodeFeature =
			new ol.Feature({
				type : 'img-label',
				geometry : point,
			});
		nodeFeature.setId(uid('L'));
		nodeFeature.set('gType', "Point");
		nodeFeature.set('labelImageURL', labelIcon);
		nodeFeature.set('labelImageScale', '0.3');
		//nodeFeature.setStyle(iconMarkerStyle);
		vectorSource.addFeature(nodeFeature);
		
		
		
		
	});
	
	
	
}