var viewableBounds;
var map;
var mapCenter;
var popup;
var serverConnector;

var mapViewerDefaultOptions = {
	osm : false,
	mapExtent : [151.211224098285,-33.8723833178949,151.223712432547,-33.8555827396741],
	mapMinZoom : 13,
	mapMaxZoom : 20,
	enableDebugConsole:false,
	showPanButton : true,
	showRotateToggleButton : true,
	showCalibrationInfo : false,
	showSearchButton : true,
	rotateMode : 'rotate-map', //rotate-map or rotate-icon
	showCompass : true,
	showEye : true,
	mapMetersPerCoordinatePoint : 1 / 5, // map scale , automatically calculated is map is geo-positioned
	aproachingNode : 3, // meters before path turn to show turn directions
	onPath : 10, // meters away from path when trigger return to path directions
	avarageWalkingSpeed : 1, // average walking speed meters per second
	orientationTrigger : 30, // min orientation change in degrees triggering  directions update
	lookRadius : 100, // scan radius in meters
	positioningMode : 'external', // positioning mode to use, valid options are 'test', 'ips', 'external'
	language : 'en'
	
};

function initMap(viewerOptions) {
	mapViewerOptions = $.extend(true, {}, mapViewerDefaultOptions, viewerOptions);
	//map = createRasterImageMap();
	map=createGeoPositionedMap();
	popup = new ol.Overlay.Popup();
	map.addOverlay(popup);
	serverConnector = new ServerConnector(false);
}



function createGeoPositionedMap() {
	var imageSize = [0, 0, 1644, 2070];
	//var mapExtent = ol.proj.transformExtent([151.238783, -33.846106, 151.244934, -33.842120], 'EPSG:4326', 'EPSG:3857');
	//var mapExtent = [ 151.211224098285,-33.8723833178949,151.223712432547,-33.8555827396741];
	var mapExtent = mapViewerOptions.mapExtent;
	
	mapCenter = ol.proj.fromLonLat([mapExtent[0]+(mapExtent[2]-mapExtent[0])/2, mapExtent[1]+(mapExtent[3]-mapExtent[1])/2]);
	var mapExtentPr = ol.proj.transformExtent(mapExtent, 'EPSG:4326', 'EPSG:3857');
	viewableBounds = mapExtentPr;

	var mapMinZoom =mapViewerOptions.mapMinZoom;
	var mapMaxZoom = mapViewerOptions.mapMaxZoom;

	var osmLayer;
	if (mapViewerOptions.osm){
		 osmLayer = new ol.layer.Tile({
				source : new ol.source.OSM()
			});
	}
	var image = new ol.layer.Image({
			source : new ol.source.ImageStatic({
				url : 'map.png',
				projection : 'EPSG:4326',
				imageSize : imageSize,
				imageExtent : mapExtent
			})
		})
		var layer = new ol.layer.Tile({
			extent : mapExtentPr,
			source : new ol.source.XYZ({
				url : "./assets/tiles/{z}/{x}/{y}.jpg",
				minZoom : mapMinZoom,
				maxZoom : mapMaxZoom
			})
		});
		var mousePositionControl = new ol.control.MousePosition({
			coordinateFormat : ol.coordinate.createStringXY(4),
			projection : 'EPSG:4326',
			// comment the following two lines to have the mouse position
			// be placed within the map.
			className : 'custom-mouse-position',
			target : document.getElementById('mouse-position'),
			undefinedHTML : '&nbsp;'
		});

	var map = new ol.Map({
			controls : ol.control.defaults({
				zoom : true,
				attribution : false,
				rotate : false
			}).extend([mousePositionControl]),
			interactions : ol.interaction.defaults().extend([
					new ol.interaction.DragRotateAndZoom()
				]),
			layers : [
				//osm,
				//image,
				//layer
			],
			target : document.getElementById('map'),
			view : new ol.View({
				center : mapCenter,
				zoom : 16,
				minZoom : mapMinZoom,
				maxZoom : mapMaxZoom
				// rotation: -initialRotation
			})
		});
	if (mapViewerOptions.osm){
	map.addLayer(osmLayer)
	}
	map.addLayer(layer)
	return map;

}

function createRasterImageMap() {
	var extent = [0, 0, 1232, 901];
	viewableBounds = extent;
	mapCenter = ol.extent.getCenter(extent);
	var mapMinZoom = 1;
	var mapMaxZoom = 3;

	var projection = new ol.proj.Projection({
			code : 'xkcd-image',
			units : 'pixels',
			extent : extent
		});

	// Create a map
	var mousePositionControl = new ol.control.MousePosition({
			coordinateFormat : ol.coordinate.createStringXY(4),
			projection : projection,
			// comment the following two lines to have the mouse position
			// be placed within the map.
			className : 'custom-mouse-position',
			target : document.getElementById('mouse-position'),
			undefinedHTML : '&nbsp;'
		});

	var map = new ol.Map({
				controls : ol.control.defaults({
				zoom : true,
				attribution : false,
				rotate : false
			}).extend([mousePositionControl]),

			interactions : ol.interaction.defaults().extend([
					new ol.interaction.DragRotateAndZoom()
				]),
			layers : [
				new ol.layer.Image({
					source : new ol.source.ImageStatic({
						url : 'map.png',
						projection : projection,
						imageExtent : extent
					})
				})
			],
			target : document.getElementById('map'),
			view : new ol.View({
				projection : projection,
				center : mapCenter,
				extent : extent,
				zoom : mapMinZoom,
				maxZoom : mapMaxZoom,
				// rotation: -initialRotation
			})
		});

	return map;

}



// creates unique id's
function uid (prefix) {
  return prefix + Math.floor((Math.random() * 100000) + 1); ;

}